@@ -143,6 +143,7 @@ modern_classmap = [(u'valo', u'sw', [(None,u'(.*)',u'valo'),
 			(u'k>j',u'(.*A)ikA',u'aika'),
 			(u'k>',u'(.*AA)kA',u'raaka'),
 			(u'k>',u'(.*)kA',u'haka')]),
+	(u'nahka', u'-', [(None,u'(.*)kA',u'nahka')]),
 	(u'koira', u'sw',   [(None,u'(.*)A',u'koira'),
 			(u'tt',u'(.*t)tA',u'kenttä'),
 			(u'nk',u'(.*n)kA',u'honka'),
@@ -181,7 +182,7 @@ modern_classmap = [(u'valo', u'sw', [(None,u'(.*)',u'valo'),
 			(None,u'(.*CO)O',u'trikoo'),
 			(None,u'(.*CU)U',u'revyy')]),
 	(u'pii', u'-', [(None,u'(.*V)i',u'pii'),
-		      (None,u'(.*CA)A',u'maa'),
+		      (None,u'(.*A)A',u'maa'),
 		      (None,u'(.*Ce)e',u'tee'),
 		      (None,u'(.*U)U',u'puu')]),
 	(u'suo', u'-', [(None,u'(.*C)UO',u'suo')]),
@@ -297,6 +298,7 @@ modern_classmap = [(u'valo', u'sw', [(None,u'(.*)',u'valo'),
 	(u'sulaa', u'sw', [(None,u'(.*C)AA',u'sulaa'),
 	                   (u'nt',u'(.*n)tAA',u'kyntää'),
 		         (u'tt',u'(.*t)tAA',u'autioittaa'),
+		         (u't',u'(.*h)tAA',u'kulahtaa'),
 		         (u'k>',u'(.*C)kAA',u'purkaa')]),
 	(u'hohtaa', u'sw', [(u'tt',u'(.*t)tAA',u'jättää'),
 	                    (u't',u'(.*)tAA',u'hohtaa')]),
@@ -406,6 +408,7 @@ modern_classmap = [(u'valo', u'sw', [(None,u'(.*)',u'valo'),
 			(u'mm',u'(.*m)mUtA',u'kummuta'),
 			(u't',u'(.*t)UtA',u'luututa'),
 			(u'p',u'(.*p)UtA',u'ryöpytä'),
+			(u'k',u'(.*k)UtA',u'takuta'),
 			(u'v',u'(.*)vUtA',u'kavuta')]),
 	(u'salata', u'ws', [(None,u'(.*)AtA',u'salata'),
 	                    (u'ng',u'(.*n)gAtA',u'hangata'),
